@@ -106,6 +106,16 @@ character class, per C<perl5234delta>. Formerly any white space
 character parsed as whitespace. This change in C<PPIx::Regexp> will be
 reverted if the change in Perl does not make it into Perl 5.24.0.
 
+=item Unescaped literal left curly brackets
+
+These are being removed in positions where quantifiers are legal, so
+that they can be used for new functionality. Some of them are gone in
+5.25.1, others will be removed in a future version of Perl. In
+situations where they have been removed,
+L<perl_version_removed()|/perl_version_removed> will return the version
+in which they were removed. When the new functionality appears, the
+parse produced by this software will reflect the new functionality.
+
 =back
 
 There are very probably other examples of this. When they come to light
@@ -113,13 +123,11 @@ they will be documented as producing the modern parse, and the code
 modified to produce this parse if necessary.
 
 The functionality that parses string literals (the C<parse> argument to
-C<new()>) was introduced in version [%% next_version $$], and should be
-considered experimental. It is a bit of a kluge in any case, especially
-in the appropriateness of class names to this use. But the actual
-parsing of a Perl string literal is not too different than the parsing
-of an C<s///> replacement string, so I thought that if someone wanted
-a string literal parse badly enough to deal with the kluginess I could
-provide it fairly easily.
+C<new()>) was introduced in version 0.045, but its use is discouraged.
+The preferred package for string literals is
+L<PPIx::QuoteLike|PPIx::QuoteLike>, and once I consider that package to
+be stable the string literal functionality in this package will be put
+through a deprecation cycle and removed.
 
 =head1 METHODS
 
@@ -143,7 +151,7 @@ use PPIx::Regexp::Tokenizer;
 use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.048';
+our $VERSION = '0.051';
 
 =head2 new
 
@@ -237,12 +245,15 @@ The default is C<'regex'>.
 
 This option is passed on to the tokenizer, where it specifies whether
 postfix dereferences are recognized in interpolations and code. This
-experimental feature was introduced in Perl 5.19.5. The default is the
-value of C<$PPIx::Regexp::Tokenizer::DEFAULT_POSTDEREF>, which is false
-by default.
+experimental feature was introduced in Perl 5.19.5.
 
-If postfix dereferencing becomes mainstream, the default value of
-C<$PPIx::Regexp::Tokenizer::DEFAULT_POSTDEREF> will become true.
+The default is the value of
+C<$PPIx::Regexp::Tokenizer::DEFAULT_POSTDEREF>, which is true. When
+originally introduced this was false, but was documented as becoming
+true when and if postfix dereferencing became mainstream. The  intent to
+mainstream was announced with Perl 5.23.1, and became official (so to
+speak) with Perl 5.24.0, so the default became true with L<PPIx::Regexp>
+0.049_01.
 
 Note that if L<PPI|PPI> starts unconditionally recognizing postfix
 dereferences, this argument will immediately become ignored, and will be
@@ -308,7 +319,7 @@ is it supported.
 
 	my $lexer = PPIx::Regexp::Lexer->new( $tokenizer, %args );
 	my @nodes = $lexer->lex();
-	my $self = $class->SUPER::_new( @nodes );
+	my $self = $class->SUPER::__new( @nodes );
 	$self->{source} = $content;
 	$self->{failures} = $lexer->failures();
 	$self->{effective_modifiers} =
@@ -358,7 +369,7 @@ any objects specified are removed from the cache.
     our $DISABLE_CACHE;		# Leave this undocumented, at least for
 				# now.
 
-    sub _cache_size {
+    sub __cache_size {
 	return scalar keys %cache;
     }
 
@@ -596,7 +607,9 @@ sub perl_version_removed {
     defined $v
 	and $v <= 5.021001
 	and return $v;
-    '??' eq $self->delimiters()
+    defined( my $delim = $self->delimiters() )
+	or return $v;
+    '??' eq $delim
 	and '' eq $self->type()->content()
 	and return '5.021001';
     return $v;
@@ -803,7 +816,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2016 by Thomas R. Wyant, III
+Copyright (C) 2009-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
