@@ -3,7 +3,7 @@ package PPIx::Regexp::Constant;
 use strict;
 use warnings;
 
-our $VERSION = '0.048';
+our $VERSION = '0.051';
 
 use base qw{ Exporter };
 
@@ -12,6 +12,9 @@ our @EXPORT_OK = qw{
     COOKIE_QUANT
     COOKIE_QUOTE
     COOKIE_REGEX_SET
+    LITERAL_LEFT_CURLY_ALLOWED
+    LITERAL_LEFT_CURLY_REMOVED_PHASE_1
+    LITERAL_LEFT_CURLY_REMOVED_PHASE_2
     MINIMUM_PERL
     MODIFIER_GROUP_MATCH_SEMANTICS
     MSG_PROHIBITED_BY_STRICT
@@ -27,6 +30,10 @@ use constant COOKIE_QUANT	=> '}';
 use constant COOKIE_QUOTE	=> '\\E';
 use constant COOKIE_REGEX_SET	=> '])';
 
+use constant LITERAL_LEFT_CURLY_ALLOWED		=> undef;
+use constant LITERAL_LEFT_CURLY_REMOVED_PHASE_1	=> '5.025001';
+use constant LITERAL_LEFT_CURLY_REMOVED_PHASE_2	=> undef;
+
 use constant MINIMUM_PERL	=> '5.000';
 
 use constant MODIFIER_GROUP_MATCH_SEMANTICS => 'match_semantics';
@@ -114,6 +121,25 @@ C<\Q> is encountered, and it persists until the next C<\E>.
 
 The name of the cookie used to control regular expression sets.
 
+=head2 LITERAL_LEFT_CURLY_ALLOWED
+
+The Perl version at which allowed unescaped literal left curly brackets
+were removed. This may make more sense if I mention that its value is
+C<undef>.
+
+=head2 LITERAL_LEFT_CURLY_REMOVED_PHASE_1
+
+The Perl version at which the first phase of unescaped literal left
+curly bracket removal took place. The value of this constant is
+C<'5.025001'>.
+
+=head2 LITERAL_LEFT_CURLY_REMOVED_PHASE_2
+
+The Perl version at which the second phase of unescaped literal left
+curly bracket removal took place. The value of this constant is
+C<undef>, but it will be assigned a value when the timing of the second
+phase is known.
+
 =head2 MINIMUM_PERL
 
 The minimum version of Perl understood by this parser, as a float. It is
@@ -168,7 +194,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2016 by Thomas R. Wyant, III
+Copyright (C) 2009-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
