@@ -44,7 +44,7 @@ use PPIx::Regexp;
 use PPIx::Regexp::Tokenizer;
 use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
 
-our $VERSION = '0.048';
+our $VERSION = '0.051';
 
 =head2 new
 
@@ -318,7 +318,7 @@ sub _safe_version {
     return defined $version ? "'$version'" : 'undef';
 }
 
-sub _nav {
+sub __nav {
     my ( $self, @args ) = @_;
     my $rslt = $self->_safe( @args );
     $rslt =~ s/ ' (\w+) ' , /$1 =>/smxg;
@@ -494,7 +494,7 @@ sub PPIx::Regexp::Node::__PPIX_DUMPER__test {
 
     my @rslt;
     @rslt = (
-	'choose  ( ' . $dumper->_nav( $self->nav() ) . ' );',
+	'choose  ( ' . $dumper->__nav( $self->nav() ) . ' );',
 	'class   ( ' . $dumper->_safe( ref $self ) . ' );',
 	'count   ( ' . scalar $self->children() . ' );',
     );
@@ -584,7 +584,6 @@ sub _format_value {
 	    and push @rslt, $self->__PPIX_DUMPER__dump_explanation(
 		$dumper, pop @rslt );
 
-	@rslt = ( join( "\t", @rslt ) );
 	my $indent = ' ' x $dumper->{indent};
 	foreach my $elem ( $self->children() ) {
 	    push @rslt, map { $indent . $_ }
@@ -602,7 +601,7 @@ sub PPIx::Regexp::Structure::__PPIX_DUMPER__test {
 
     my @nav = $self->nav();
     my @rslt = (
-	'choose  ( ' . $dumper->_nav( @nav ) . ' );',
+	'choose  ( ' . $dumper->__nav( @nav ) . ' );',
 	'class   ( ' . $dumper->_safe( ref $self ) . ' );',
 	'count   ( ' . scalar $self->children() . ' );',
     );
@@ -615,12 +614,12 @@ sub PPIx::Regexp::Structure::__PPIX_DUMPER__test {
     }
     foreach my $method ( qw{ start type finish } ) {
 	my @eles = $self->$method();
-	push @rslt, 'choose  ( ' . $dumper->_nav(
+	push @rslt, 'choose  ( ' . $dumper->__nav(
 	    @nav, $method, [] ) . ' );',
 	    'count   ( ' . scalar @eles . ' );';
 	foreach my $inx ( 0 .. $#eles ) {
 	    my $elem = $eles[$inx];
-	    push @rslt, 'choose  ( ' . $dumper->_nav(
+	    push @rslt, 'choose  ( ' . $dumper->__nav(
 		@nav, $method, $inx ) . ' );',
 		'class   ( ' . $dumper->_safe( ref $elem || $elem ) . ' );',
 		'content ( ' . $dumper->_safe( $elem ) . ' );';
@@ -713,7 +712,7 @@ sub PPIx::Regexp::Token::__PPIX_DUMPER__test {
 
     @nav or @nav = $self->nav();
     my @rslt = (
-	'choose  ( ' . join(', ', $dumper->_nav( @nav ) ) . ' );',
+	'choose  ( ' . join(', ', $dumper->__nav( @nav ) ) . ' );',
 	'class   ( ' . $dumper->_safe( ref $self ) . ' );',
 	'content ( ' . $dumper->_safe( $self ) . ' );',
     );
@@ -771,7 +770,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2016 by Thomas R. Wyant, III
+Copyright (C) 2009-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
