@@ -42,11 +42,11 @@ use PPIx::Regexp::Constant qw{ MINIMUM_PERL NODE_UNKNOWN };
 use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.048';
+our $VERSION = '0.051';
 
 use constant ELEMENT_UNKNOWN	=> NODE_UNKNOWN;
 
-sub _new {
+sub __new {
     my ( $class, @children ) = @_;
     ref $class and $class = ref $class;
     foreach my $elem ( @children ) {
@@ -397,7 +397,7 @@ sub unescaped_content {
 }
 
 # Help for nav();
-sub _nav {
+sub __nav {
     my ( $self, $child ) = @_;
     refaddr( $child->parent() ) == refaddr( $self )
 	or return;
@@ -456,7 +456,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2016 by Thomas R. Wyant, III
+Copyright (C) 2009-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
