@@ -52,11 +52,11 @@ use PPIx::Regexp::Constant qw{ STRUCTURE_UNKNOWN };
 use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.048';
+our $VERSION = '0.051';
 
 use constant ELEMENT_UNKNOWN => STRUCTURE_UNKNOWN;
 
-sub _new {
+sub __new {
     my ( $class, @args ) = @_;
     my %brkt;
     if ( ref $args[0] eq 'HASH' ) {
@@ -81,7 +81,7 @@ sub _new {
 
     $class->_check_for_interpolated_match( \%brkt, \@args );
 
-    my $self = $class->SUPER::_new( @args )
+    my $self = $class->SUPER::__new( @args )
 	or return;
 
     if ( __instance( $brkt{type}[0], 'PPIx::Regexp::Token::GroupType' ) ) {
@@ -365,7 +365,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2016 by Thomas R. Wyant, III
+Copyright (C) 2009-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
