@@ -36,10 +36,13 @@ use warnings;
 use base qw{ PPIx::Regexp::Token::CharClass };
 
 use PPIx::Regexp::Constant qw{
-    COOKIE_CLASS MINIMUM_PERL TOKEN_LITERAL TOKEN_UNKNOWN
+    COOKIE_CLASS
+    LITERAL_LEFT_CURLY_REMOVED_PHASE_1
+    LITERAL_LEFT_CURLY_REMOVED_PHASE_2
+    MINIMUM_PERL TOKEN_LITERAL TOKEN_UNKNOWN
 };
 
-our $VERSION = '0.048';
+our $VERSION = '0.051';
 
 {
 
@@ -104,38 +107,38 @@ our $VERSION = '0.048';
 ##    return ( $self->{is_case_sensitive} = $self->_is_case_sensitive() );
 ##}
 
-{
-    my %case_sensitive = map { $_ => 1 } qw{
-        generalcategory=lowercaseletter generalcategory=ll
-	    gc=lowercaseletter gc=ll
-        generalcategory=titlecaseletter generalcategory=lt
-	    gc=titlecaseletter gc=lt
-        generalcategory=uppercaseletter generalcategory=lu
-	    gc=uppercaseletter gc=lu
-	lowercaseletter lowercase lower ll
-	titlecaseletter titlecase title lt
-	uppercaseletter uppercase upper lu
-	lowercase=y lower=y lowercase=n lower=n
-	titlecase=y title=y titlecase=n title=n
-	uppercase=y upper=y uppercase=n upper=n
-    };
-
-    sub _is_case_sensitive {
-	my ( $self ) = @_;
-	my $content = $self->content();
-	$content =~ m/ \A \\ p [{] ( .* ) [}] /smxi
-	    or return 0;
-	$content = lc $1;
-	$content =~ s/ \A ^ //smx;
-	$content =~ s/ [\s_-] //smxg;
-	$content =~ s/ \A is //smx;
-	$content =~ s/ : /=/smxg;
-	$content =~ s/ = (?: yes | t | true ) \b /=y/smxg;
-	$content =~ s/ = (?: no | f | false ) \b /=n/smxg;
-	return $case_sensitive{$content} || 0;
-    }
-
-}
+##{
+##    my %case_sensitive = map { $_ => 1 } qw{
+##        generalcategory=lowercaseletter generalcategory=ll
+##	    gc=lowercaseletter gc=ll
+##        generalcategory=titlecaseletter generalcategory=lt
+##	    gc=titlecaseletter gc=lt
+##        generalcategory=uppercaseletter generalcategory=lu
+##	    gc=uppercaseletter gc=lu
+##	lowercaseletter lowercase lower ll
+##	titlecaseletter titlecase title lt
+##	uppercaseletter uppercase upper lu
+##	lowercase=y lower=y lowercase=n lower=n
+##	titlecase=y title=y titlecase=n title=n
+##	uppercase=y upper=y uppercase=n upper=n
+##    };
+##
+##    sub _is_case_sensitive {
+##	my ( $self ) = @_;
+##	my $content = $self->content();
+##	$content =~ m/ \A \\ p [{] ( .* ) [}] /smxi
+##	    or return 0;
+##	$content = lc $1;
+##	$content =~ s/ \A ^ //smx;
+##	$content =~ s/ [\s_-] //smxg;
+##	$content =~ s/ \A is //smx;
+##	$content =~ s/ : /=/smxg;
+##	$content =~ s/ = (?: yes | t | true ) \b /=y/smxg;
+##	$content =~ s/ = (?: no | f | false ) \b /=n/smxg;
+##	return $case_sensitive{$content} || 0;
+##    }
+##
+##}
 
 {
 
@@ -180,6 +183,20 @@ our $VERSION = '0.048';
     }
 }
 
+# This is one of the larger complications of
+# https://rt.perl.org/Public/Bug/Display.html?id=128213
+# where it transpired that un-escaped literal left curlies were not
+# giving warnings/errors in /.{/, /\p{...}{/, and /\P{...}{/, but were
+# for all the others that bin into this class (e.g. /\s{/).
+sub __following_literal_left_curly_disallowed_in {
+    my ( $self ) = @_;
+    q<.> eq ( my $content = $self->content() )
+	and return LITERAL_LEFT_CURLY_REMOVED_PHASE_2;
+    $content =~ m/ \A \\ p \{ /smxi
+	and return LITERAL_LEFT_CURLY_REMOVED_PHASE_2;
+    return LITERAL_LEFT_CURLY_REMOVED_PHASE_1;
+}
+
 sub __PPIX_TOKENIZER__regexp {
     my ( undef, $tokenizer, $character ) = @_;
 
@@ -231,7 +248,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2016 by Thomas R. Wyant, III
+Copyright (C) 2009-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
