@@ -22,8 +22,8 @@ object of this class.
 
 =head1 METHODS
 
-This class provides no public methods beyond those provided by its
-superclass.
+This class provides the following public methods beyond those provided
+by its superclass.
 
 =cut
 
@@ -40,7 +40,7 @@ use PPIx::Regexp::Constant qw{
     COOKIE_CLASS COOKIE_REGEX_SET TOKEN_LITERAL MINIMUM_PERL
 };
 
-our $VERSION = '0.048';
+our $VERSION = '0.051';
 
 use constant VERSION_WHEN_IN_REGEX_SET => '5.017009';
 
@@ -283,7 +283,8 @@ sub _interpolation {
 
 # Return true if we think a curly-bracketed subscript is really a
 # subscript, rather than a quantifier.
-sub _curly {
+# Called as $class->$handler( ... ) above
+sub _curly {	## no critic (ProhibitUnusedPrivateSubroutines)
     my ( undef, @kids ) = @_;		# Invocant unused
 
     # If the first child is a word, and either it is an only child or
@@ -314,7 +315,8 @@ sub _curly {
 
 # Return true if we think a square-bracketed subscript is really a
 # subscript, rather than a character class.
-sub _square {
+# Called as $class->$handler( ... ) above
+sub _square {	## no critic (ProhibitUnusedPrivateSubroutines)
     my ( undef, @kids ) = @_;		# Invocant unused
 
     # We expect to have either a number or a symbol as the first
@@ -440,7 +442,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2016 by Thomas R. Wyant, III
+Copyright (C) 2009-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
