@@ -37,11 +37,12 @@ use base qw{ PPIx::Regexp::Token };
 
 use PPIx::Regexp::Constant qw{
     COOKIE_CLASS COOKIE_REGEX_SET
+    LITERAL_LEFT_CURLY_ALLOWED
     TOKEN_LITERAL
 };
 use PPIx::Regexp::Util qw{ __instance };
 
-our $VERSION = '0.048';
+our $VERSION = '0.051';
 
 use constant TOKENIZER_ARGUMENT_REQUIRED => 1;
 
@@ -152,6 +153,20 @@ sub _treat_as_literal {
 
 }
 
+{
+    my $removed_in = {
+	'|'	=> LITERAL_LEFT_CURLY_ALLOWED,	# Allowed after alternation
+    };
+
+    sub __following_literal_left_curly_disallowed_in {
+	my ( $self ) = @_;
+	my $content = $self->content();
+	exists $removed_in->{$content}
+	    and return $removed_in->{$content};
+	return $self->SUPER::__following_literal_left_curly_disallowed_in();
+    }
+}
+
 sub __PPIX_TOKENIZER__regexp {
     my ( undef, $tokenizer, $character ) = @_;
 
@@ -191,7 +206,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2016 by Thomas R. Wyant, III
+Copyright (C) 2009-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
