@@ -18,11 +18,14 @@ C<PPIx::Regexp::Token::Whitespace> has no descendants.
 =head1 DESCRIPTION
 
 This class represents whitespace. It will appear inside the regular
-expression only if the /x modifier is present, but it may also appear
+expression only if the C</x> modifier is present, but it may also appear
 between the type and the opening delimiter (e.g. C<qr {foo}>) or after
 the regular expression in a bracketed substitution (e.g. C<s{foo}
 {bar}>).
 
+If the C</xx> modifier is present, it can also appear inside bracketed
+character classes. This was introduced in Perl 5.25.9.
+
 =head1 METHODS
 
 This class provides no public methods beyond those provided by its
@@ -39,7 +42,7 @@ use base qw{ PPIx::Regexp::Token::NoOp };
 
 use PPIx::Regexp::Constant qw{ COOKIE_REGEX_SET MINIMUM_PERL };
 
-our $VERSION = '0.048';
+our $VERSION = '0.051';
 
 sub __new {
     my ( $class, $content, %arg ) = @_;
@@ -63,8 +66,8 @@ sub explain {
 	return $self->SUPER::explain();
     } elsif ( $self->in_regex_set() ) {
 	return q<Not significant in extended character class>;
-    } elsif ( $self->modifier_asserted( 'x' ) ) {
-	return q<Not significant under /x>;
+    } elsif ( my $count = $self->modifier_asserted( 'x*' ) ) {
+	return q<Not significant under /> . ( 'x' x $count );
     } else {
 	return $self->SUPER::explain();
     }
@@ -101,7 +104,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2016 by Thomas R. Wyant, III
+Copyright (C) 2009-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
